@@ -3,7 +3,7 @@ package WordList;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-22'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.6.1'; # VERSION
+our $VERSION = '0.6.2'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -75,12 +75,10 @@ sub first_word {
 }
 
 sub pick {
-    my ($self, $n, $allow_duplicates) = @_;
+    my ($self, $n, $allow_duplicates) = @_; # but this implementaiton never produces duplicates
 
     $n = 1 if !defined $n;
     die "Please specify a positive number of words to pick" if $n < 1;
-    die "This implementation of pick() does not produce duplicates"
-        if $allow_duplicates;
 
     if ($n == 1) {
         my $i = 0;
@@ -155,7 +153,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.6.1 of WordList (from Perl distribution WordList), released on 2020-05-22.
+This document describes version 0.6.2 of WordList (from Perl distribution WordList), released on 2020-05-22.
 
 =head1 SYNOPSIS
 
